@@ -6,11 +6,12 @@ class BaseFile():
     Base file class that can be utilized by any
     object that represents a file. The class is
     initialized with a filepath, either relative or
-    hardcoded.
+    absolute.
     """
 
-    def __init__(self, filepath):
-        self.filepath = filepath
+    def __init__(self, filepath):  # add a parameter that accepts
+        self.filepath = filepath   # and adds contents to file.
+        self.is_encrypted = self.is_binary()
 
     def set_filepath(self, filepath):
         self.filepath = filepath
@@ -20,7 +21,7 @@ class BaseFile():
 
     def create_filepath(self):
         """
-        Creates filepaths for both dirs and files.
+        Creates filepath for both dirs and files.
         First creates the directory paths and then tries
         to create the filepath if the filepath is a file.
         """
@@ -34,34 +35,44 @@ class BaseFile():
     def delete_file(self):
         """
         Utilizes the remove method from the os module.
-        Checks if the filepath exists and that the path
-        is not a dir before deleting.
+        Only deletes files. If file is not found a
+        FileNotFoundError is raised. If the filepath
+        is a directory, a IsADirectoryError is raised.
         """
-        if self.filepath_exists() and self.is_file():
-            remove(self.filepath)
-        else:
-            print("The file could not be deleted because "
-                  + self.filepath + " does not exist or it is a directory.")
+        remove(self.filepath)
+
+    def clear_file(self):
+        """
+        Utilizes the file truncate() function.
+        If file is not found a FileNotFoundError
+        is raised. If the filepath is a directory,
+        a IsADirectoryError is raised.
+        """
+        with open(self.filepath, 'r+') as f:
+            f.truncate()
 
     def get_contents_of_file(self):
         """
         Returns all the text read from the file.
+        If the file is not text, it will return
+        UnicodeDecodeError.
         """
         data = None
         with open(self.filepath, 'r') as my_file:
             data = my_file.read()
         return data
 
-    def append_data_to_file(self, data):
+    def append_text_to_file(self, data):
         """
-        Appends text to the file. Does not delete
+        Creates file if it does not exist and
+        appends text to the file. Does not delete
         the file or clear the contents.
         """
         with open(self.filepath, 'a') as f:
             f.write(data)
             f.close()
 
-    def write_data_to_file(self, data):
+    def write_text_to_file(self, data):
         """
         Truncates the file and writes the
         data as text.
@@ -70,55 +81,47 @@ class BaseFile():
             f.write(data)
             f.close()
 
-    def clear_file(self):
-        """
-        Checks if the file exists before truncating
-        the file. Performs an open, write, close which
-        clears all the contents.
-        """
-        if self.filepath_exists():
-            open(self.filepath, 'w').close()
-        else:
-            print("The file could not be cleared because "
-                  + self.filepath + " does not exist.")
-
     def is_binary(self):
         """
-        A simple method to determine if the file
+        A method to determine if the file
         is not a text file. If UnicodeDecodeError
         is thrown, it is not a text file. In our
         case, we are assuming it is a binary. This
         method is called at the initialization of
         EncryptionFile, so it needs to work when
         the file does not exist, hence the
-        FileNotFoundError.
+        FileNotFoundError. This function will return
+        False if the file is a directory.
         """
         try:
             with open(self.filepath, "r") as f:
                 f.read()
         except UnicodeDecodeError:
             return True
-        except FileNotFoundError:
+        except (FileNotFoundError, IsADirectoryError):
             return False
         return False
 
-    def is_empty(self, verbose_flag=False):
+    def is_empty(self):
         """
-        Returns boolean if size of file is 0.
+        Returns False if size of file is 0.
+        If the self.filepath is a directory,
+        the stat function returns 4096, which returns
+        True.
         """
         if stat(self.filepath).st_size == 0:
             return True
         else:
             return False
 
-    def is_dir(self, verbose_flag=False):
+    def is_dir(self):
         """
         Utilizes the path(filepath).isdir() function
         from the os module.
         """
         return path.isdir(self.filepath)
 
-    def is_file(self, verbose_flage=False):
+    def is_file(self):
         """
         Utilizes the path(filepath).isfile() function
         from the os module.
@@ -134,5 +137,27 @@ class BaseFile():
         else:
             return False
 
+    def is_decryptable(self):
+        """
+        If filepath is a dir, returns False.
+        Determines if filepath exists and the file
+        is a binary.
+        """
+        if self.is_dir():
+            return False
+        else:
+            return self.filepath_exists() and self.is_encrypted
+
+    def is_encryptable(self):
+        """
+        If filepath is a dir, returns False.
+        Determines if filepath exists and the file is not
+        a binary.
+        """
+        if self.is_dir():
+            return False
+        else:
+            return self.filepath_exists() and not self.is_encrypted
+
     def __str__(self):
         return self.filepath
