@@ -1,7 +1,5 @@
 from Crypto.Cipher import PKCS1_v1_5 as Cipher_PKCS1_v1_5
 from Crypto.PublicKey import RSA
-from os import path, strerror
-from errno import ENOENT
 
 
 class Encryptor():
@@ -13,12 +11,7 @@ class Encryptor():
     """
 
     def __init__(self, rsa_filepath):
-        if path.exists(rsa_filepath):
-            self.pem_key = self.get_key(rsa_filepath)
-        else:
-            raise FileNotFoundError(
-                ENOENT, strerror(ENOENT),
-                rsa_filepath)
+        self.pem_key = self.get_key(str(rsa_filepath))
 
     def encrypt_data(self, data):
         cipher = Cipher_PKCS1_v1_5.new(self.pem_key)
